==> billogram-foundation-2.0.2.tgz: package/modules/components/textbox/Textbox.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../isNullOrEmpty';
import toNumber from './utils/toNumber';


export default ({
    block,
    displayName
}= {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            error: PropTypes.bool,
            maxLength: PropTypes.string,
            onChange: PropTypes.func,
            placeholder: PropTypes.string,
            type: PropTypes.oneOf(['float', 'integer', 'text']),
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                error: false,
                onChange: (/* { rawValue, value } */) => {},
                placeholder: '',
                type: 'text',
                value: ''
            };
        },

        onChange(evt) {
            const { onChange, type } = this.props;

            const rawValue = evt.target.value;
            const { value, valid } = type === 'float' || type === 'integer'
                ? toNumber(rawValue, type)
                : { value: rawValue, valid: true };

            if (valid) {
                onChange({ rawValue, value });
            }
        },

        render() {
            const { disabled, error, maxLength, placeholder, value } = this.props;
            return (
                <input
                    type="text"
                    className={ block({ disabled, error }) }
                    disabled={ disabled }
                    maxLength={ maxLength }
                    onChange={ this.onChange }
                    placeholder={ placeholder }
                    value={ value } />
            );
        }

    });

};

==> billogram-foundation-3.10.0.tgz: package/modules/components/textbox/Textbox.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../isNullOrEmpty';
import toNumber from './utils/toNumber';


export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            error: PropTypes.bool,
            focus: PropTypes.bool,
            maxLength: PropTypes.string,
            onChange: PropTypes.func,
            placeholder: PropTypes.string,
            type: PropTypes.oneOf(['float', 'integer', 'password', 'text']),
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                error: false,
                focus: false,
                onChange: (/* { rawValue, value } */) => {},
                placeholder: '',
                type: 'text',
                value: ''
            };
        },

        componentDidMount() {
            this.focus();
        },

        componentDidUpdate() {
            this.focus();
        },

        onChange(evt) {
            const { onChange, type } = this.props;

            const rawValue = evt.target.value;
            const { value, valid } = type === 'float' || type === 'integer'
                ? toNumber(rawValue, type)
                : { value: rawValue, valid: true };

            if (valid) {
                onChange({ rawValue, value });
            }
        },

        focus() {
            if (this.props.focus) {
                this.input.focus();
                this.input.select();
            }
        },

        render() {
            const { disabled, error, maxLength, placeholder, type, value } = this.props;
            return (
                <input
                    type={ type === 'password' ? 'password' : 'text' }
                    className={ block({ disabled, error }) }
                    disabled={ disabled }
                    maxLength={ maxLength }
                    onChange={ this.onChange }
                    placeholder={ placeholder }
                    ref={ (c) => this.input = c }
                    value={ value } />
            );
        }

    });

};
